==> haskell-lrucache-1.2.0.1-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lrucache
version:              1.2.0.1
visibility:           public
id:                   lrucache-1.2.0.1-85TckKKmxOiF6EAQ5zFLML
key:                  lrucache-1.2.0.1-85TckKKmxOiF6EAQ5zFLML
license:              BSD-3-Clause
copyright:            Carl Howells, 2010-2015
maintainer:           chowells79@gmail.com
author:               Carl Howells
stability:            Experimental
homepage:             http://github.com/chowells79/lrucache
synopsis:             a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".

    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.

category:             Data
abi:                  04d6e6acb24a2588692e745e8997601b
exposed:              True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lrucache-1.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lrucache
hs-libraries:         HSlrucache-1.2.0.1-85TckKKmxOiF6EAQ5zFLML
depends:
    base-4.16.4.0 containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq

haddock-interfaces:   /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html:         /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lrucache-1.2.0.1-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lrucache
version:              1.2.0.1
visibility:           public
id:                   lrucache-1.2.0.1-KqXn3rxkxjHdBTKj3hx2H
key:                  lrucache-1.2.0.1-KqXn3rxkxjHdBTKj3hx2H
license:              BSD-3-Clause
copyright:            Carl Howells, 2010-2015
maintainer:           chowells79@gmail.com
author:               Carl Howells
stability:            Experimental
homepage:             http://github.com/chowells79/lrucache
synopsis:             a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".

    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.

category:             Data
abi:                  6684a4b5d4c34150d4d5793bee24dbdf
exposed:              True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lrucache-1.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lrucache-1.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lrucache
hs-libraries:         HSlrucache-1.2.0.1-KqXn3rxkxjHdBTKj3hx2H
depends:
    base-4.17.2.1 containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi

haddock-interfaces:   /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html:         /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
